==> deepin-deb-installer_5.8.1.orig.tar.gz: deepin-deb-installer-5.8.1/assets/deepin-deb-installer/package-installer/zh_CN/package-installer.md <==
# 软件包安装器|deepin-deb-installer|

## 概述

软件包安装器是一款deb包管理工具，方便用户安装商店以外的自定义应用。界面简单易用，支持批量安装、版本信息识别和依赖自动补全等功能，帮助您快速的实现安装操作。

   ![0|run](fig/run.png)

## 操作介绍


### 打开方式

您可以使用以下方法打开软件包安装器：

- 双击deb包，软件包安装器会自动启动并准备安装该软件包。
- 直接将deb包拖拽到软件包安装器的图标上打开应用。

### 安装

软件包安装器可以安装单个应用，也可以批量安装多个应用。

#### 单个安装

1.  在软件包安装器界面，您可以：
   - 单击 **选择文件** ，选择需要安装的软件包，单击 **打开**。
   - 直接将软件包拖拽到应用界面。
2.  单击 **安装**。
3.  如果弹出授权窗口，请输入密码授权。
4.  安装过程中可以单击 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展开或收起安装进程信息。
5.  安装成功之后，单击 **完成** 退出，或者单击 **返回** 继续安装其他应用。

   ![0|success](fig/success.png)

#### 多个安装

软件包安装器可以通过拖拽和选择文件的方式一次性批量添加多个软件包，安装步骤请参考 [单个安装](#单个安装)，多个安装时请注意以下要点：

- 批量安装同样也可以查看安装进程。
- 批量安装时按钮只显示 **安装** 按钮。本地已安装其他版本的软件包执行安装操作，本地已安装相同版本的软件包执行重新安装操作。
- 批量安装列表内，选择一个安装包，单击鼠标右键选择 **删除** 可将安装包从列表中移除。

   ![0|mult](fig/multi.png)

#### 无法安装

软件包安装器可以自动识别无法安装的包，有效规避安装后无法使用的问题。

请留意界面提示并确定，常见的原因有：

- 软件包架构不匹配。
  
   ![0|cant](fig/cant1.png) 
  
- 依赖关系不满足。  
  
   ![0|cant](fig/cant2.png)


- 安装包无数字签名。
  
   请根据对话框提示，在 **控制中心 > 通用** 中开启开发者模式后，再进行安装。
   
   ![0|cant](fig/cant3.png)
   
- 安装包没有有效的数字签名。

   ![0|cant](fig/cant4.png)
   


### 卸载

当安装包已存在相同或其他版本时，可以使用软件包安装器执行卸载操作。

1.  在软件包安装器界面，您可以：
   - 单击 **选择文件** ，选择需要安装的软件包，单击 **打开**。
   - 直接将软件包拖拽到应用界面。
2. 单击 **卸载**。
3. 请注意界面上的卸载提示，单击 **确定卸载**。如果弹出授权窗口，请输入密码授权。
4. 卸载过程中可以单击 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展开或收起卸载进程信息。
5.  卸载成功后单击 **完成**。

![0|uninstall](fig/uninstall.png)

> ![attention](../common/attention.svg)注意：卸载某些应用可能会对系统或其他软件产生影响，请谨慎操作。

> ![notes](../common/notes.svg)说明：若检测到已安装的软件版本较新时，则显示 **安装旧版本** 按钮，您可退回到旧版本；若检测到已安装的软件版本较旧时，则显示 **更新** 按钮，您可更新版本。

## 主菜单

在主菜单中，您可以切换窗口主题、查看帮助手册、了解软件包安装器的更多信息。

### 主题

窗口主题包含浅色主题、深色主题和跟随系统主题。

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **主题**，选择一个主题颜色。

### 帮助

查看帮助手册，进一步了解和使用软件包安装器。

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **帮助**。
3. 查看软件包安装器的帮助手册。


### 关于

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **关于**。
3. 查看软件包安装器的版本和介绍。


### 退出

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **退出**。

==> deepin-deb-installer_6.5.5.orig.tar.gz: deepin-deb-installer-6.5.5/assets/deepin-deb-installer/package-installer/zh_CN/package-installer.md <==
# 软件包安装器|deepin-deb-installer|

## 概述

软件包安装器是一款deb包管理工具，界面简单易用，支持批量安装、版本信息识别和依赖包自动补全等功能，帮助您快速的实现安装操作。

![0|run](fig/run.png)


## 操作介绍

### 打开方式

您可以使用以下方法打开软件包安装器：

- 双击deb包，软件包安装器会自动启动并准备安装该软件包。
- 直接将deb包拖拽到软件包安装器的图标上打开应用。

### 安装

软件包安装器可以安装单个应用，也可以批量安装多个应用。

#### 单个安装

1.  在软件包安装器界面，您可以：
   - 单击 **选择文件** ，选择需要安装的软件包，单击 **打开**。
   - 直接将软件包拖拽到应用界面。
2.  单击 **安装**，弹出授权窗口，请输入密码授权。
3.  安装过程中可以单击 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展开或收起安装进程信息。
4.  安装成功之后，单击 **完成** 退出，或者单击 **返回** 继续安装其他应用。

![0|success](fig/success.png)

> ![notes](../common/notes.svg) 说明：当检测到已安装的软件版本高于或低于待安装的版本时，界面会显示 **安装旧版本** 或 **更新** 按钮，您可以根据需要退回到旧版本或更新到新版本。



#### 多个安装

软件包安装器可以通过拖拽和选择文件的方式一次性批量添加多个软件包，安装步骤请参考 [单个安装](#单个安装)，多个安装时请注意以下要点：

- 批量安装同样也可以查看安装进程。
- 批量安装时按钮只显示 **安装** 按钮。本地已安装其他版本的软件包执行安装操作，本地已安装相同版本的软件包执行重新安装操作。
- 批量安装列表内，选择一个安装包，单击鼠标右键选择 **删除** 可将安装包从列表中移除。


![0|mult](fig/multi.png)

#### 无法安装

软件包安装器可以自动识别无法安装的包，有效规避安装后无法使用的问题。

常见的原因有：

- 软件包架构不匹配。
  

![0|cant](fig/cant1.png)

- 依赖关系不满足。

![0|cant](fig/cant2.png)


### 卸载

当安装包已存在相同或其他版本时，可以使用软件包安装器执行卸载操作。

1.  在软件包安装器界面，您可以：
   - 单击 **选择文件** ，选择需要安装的软件包，单击 **打开**。
   - 直接将软件包拖拽到应用界面。
2. 单击 **卸载**。
3. 请注意界面上的卸载提示，单击 **确定卸载**，弹出授权窗口，请输入密码授权。
4. 卸载过程中可以单击 ![arrowdown_icon](../common/down.svg) 或 ![arrowup_icon](../common/up.svg) 展开或收起卸载进程信息。
5.  卸载成功后单击 **完成**。

![0|uninstall](fig/uninstall.png)

> ![attention](../common/attention.svg) 注意：卸载某些应用可能会对系统或其他软件产生影响，请谨慎操作。



## 主菜单

在主菜单中，您可以切换窗口主题、查看帮助手册、了解软件包安装器的更多信息。

### 主题

窗口主题包含浅色主题、深色主题和跟随系统主题。

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **主题**，选择一个主题颜色。

### 帮助

查看帮助手册，进一步了解和使用软件包安装器。

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **帮助**。
3. 查看软件包安装器的帮助手册。


### 关于

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **关于**。
3. 查看软件包安装器的版本和介绍。


### 退出

1. 在软件包安装器界面，单击 ![icon_menu](../common/icon_menu.svg)。
2. 选择 **退出**。
